@@ -16,7 +16,7 @@
 #
 #  High level module for managing the lookup of R objects.
 #
-#  $Id: rpy.py 387 2007-11-30 00:57:41Z warnes $
+#  $Id: rpy.py 489 2008-04-16 14:19:47Z warnes $
 #
 #
 from __future__ import nested_scopes
@@ -181,6 +181,7 @@ RPyRException = _rpy.RPy_RException
 # for backwards compatibility
 RException = RPyException
 
+Robj = _rpy.Robj
 
 
 # I/O setters
@@ -194,10 +195,21 @@ if sys.platform != 'win32':
     get_rpy_showfiles = _rpy.get_showfiles
 
 # Default I/O to functions in the 'rpy_io' module
-set_rpy_output(rpy_io.rpy_output)
-set_rpy_input(rpy_io.rpy_input)
-if sys.platform != 'win32':
-    set_rpy_showfiles(rpy_io.rpy_showfiles)
+if rpy_options['SETUP_WRITE_CONSOLE']:
+    set_rpy_output(rpy_io.rpy_output)
+else:
+    print "\nSkipping initialization of R console *write* support.\n"
+
+if rpy_options['SETUP_READ_CONSOLE']:
+    set_rpy_input(rpy_io.rpy_input)
+else:
+    print "\nSkipping initialization of R console *read* support.\n"
+
+if rpy_options['SETUP_SHOWFILES']:
+    if sys.platform != 'win32':
+        set_rpy_showfiles(rpy_io.rpy_showfiles)
+else:
+    print "\nSkipping initialization of R console *file viewer* support\n"    
 
 # Functions for processing events
 import threading
@@ -320,7 +332,7 @@ class R:
         self.print_(helpobj)
 
     def __repr__(self):
-        Rver = self.__getitem__('R_version_string')
+        Rver = self.__getitem__('R.version.string')
         return "RPy version %s [%s]" % (rpy_version, Rver)
 
     def __str__(self):
