@@ -28,14 +28,23 @@ rpy_options = {
   'RVER':None,        # R Version *number*
   'RUSER':None,       # R User's Home Directory
   'USE_NUMERIC':None, # Is Numeric module available
-  'VERBOSE':False      # Should status messages be displated.
+  'VERBOSE':False,      # Should status messages be displated.
+  'SETUP_READ_CONSOLE':  True,  # Set to False to prevent standard console read config
+  'SETUP_WRITE_CONSOLE': True,  # Set to False to prevent standard console write config
+  'SETUP_SHOWFILES':     True   # Set to False to prevent standard console file viewerd config
   }
 
-def set_options(RHOME=None, USE_NUMERIC=None, VERBOSE=None):
+def set_options(RHOME=None, USE_NUMERIC=None, VERBOSE=None, SETUP_READ_CONSOLE=None, SETUP_WRITE_CONSOLE=None, SETUP_SHOWFILES=None):
   if RHOME != None and os.path.isdir(RHOME):
     rpy_options['RHOME'] = RHOME
   if USE_NUMERIC != None and USE_NUMERIC in [True, False]:
     rpy_options['USE_NUMERIC'] = USE_NUMERIC
   if VERBOSE != None and VERBOSE in [True, False]:
     rpy_options['VERBOSE'] = VERBOSE
+  if SETUP_READ_CONSOLE != None and SETUP_READ_CONSOLE in [True, False]:
+    rpy_options['SETUP_READ_CONSOLE'] = VERBOSE
+  if SETUP_WRITE_CONSOLE != None and SETUP_WRITE_CONSOLE in [True, False]:
+    rpy_options['SETUP_WRITE_CONSOLE'] = VERBOSE
+  if SETUP_SHOWFILES != None and SETUP_SHOWFILES in [True, False]:
+    rpy_options['SETUP_SHOWFILES'] = VERBOSE
   
