@@ -53,9 +53,9 @@ def get_R_HOME(force_exec=False):
     if sys.platform == 'win32':
       stat, rhome = getstatusoutput('R RHOME')
     else:
-      stat, rhome = getstatusoutput('R RHOME | tail -1')
+      stat, rhome = getstatusoutput('R RHOME | tail -n 1')
     if stat or len(rhome)<=0:
-      raise RuntimeExecError("Couldn't execute the R interpreter.\n"
+      raise RuntimeError("Couldn't execute the R interpreter.\n"
                              "Check whether R is in the execution path.")
     
   rhome = rhome.strip()
