@@ -1,5 +1,5 @@
 /*
- * $Id: io.c 299 2006-03-22 22:13:54Z warnes $ 
+ * $Id: io.c 393 2008-01-02 17:34:28Z warnes $ 
  * Input/Output routines
  */
 
@@ -98,12 +98,14 @@ RPy_WriteConsole(char *buf, int len)
 int
 RPy_ReadConsole(char *prompt, 
                 char *buf, 
-                int len, int addtohistory)
+                int len, 
+		int addtohistory)
 #else
 int
 RPy_ReadConsole(char *prompt, 
                 unsigned char *buf, 
-                int len, int addtohistory)
+                int len, 
+		int addtohistory)
 #endif
 {
   PyObject *input_data;
@@ -258,7 +260,9 @@ get_showfiles(PyObject *self, PyObject *args)
 void
 init_io_routines(void)
 #ifdef _WIN32
-{ return; }
+{ 
+  return; 
+}
 #else
 {
   R_Outputfile = NULL;
