@@ -1,5 +1,5 @@
 /*
- * $Id: rpymodule.c 384 2007-11-30 00:40:17Z warnes $
+ * $Id: rpymodule.c 510 2008-05-09 21:16:59Z warnes $
  * Implementation of the module '_rpy' and the 'Robj' type.
  */
 
@@ -39,7 +39,15 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-#define CSTACK_DEFNS
+#include <Rversion.h> 
+#if (R_VERSION >= R_Version(2,3,0)) 
+
+#  ifndef _WIN32
+#    define CSTACK_DEFNS // Enable definitions needed for stack checking control
+#  endif 
+
+#endif
+
 #include "RPy.h"
 
 #define NONAMELESSUNION
@@ -62,7 +70,7 @@ static PyObject *r_init(PyObject *self,   /* Class initializer */
 static PyObject *r_cleanup(void);         /* Clean up R & release resources */
 
 #ifdef _WIN32
-static void init_embedded_win32( void );
+static void init_embedded_win32(int argc, char *argv[]);
 #endif
 
 /* Global objects */
@@ -82,6 +90,8 @@ static char RHOME[BUFSIZ];
 static char RVERSION[BUFSIZ];
 static char RVER[BUFSIZ];
 static char RUSER[BUFSIZ];
+char *defaultargv[] = {"rpy", "-q", "--vanilla"};
+int  defaultargc = sizeof(defaultargv) / sizeof(defaultargv[0]);
 
 /* Global interpreter */
 PyInterpreterState *my_interp;
@@ -1473,16 +1483,95 @@ Robj_item(PyObject *a, int i)
   return obj;
 }
 
+/* Get a slice: a[x:y] */
+/*FIXME: starting with Python 2.5, ilow and ihigh should probably
+ * be of type Py_ssize_t.
+ */
+static PyObject * 
+Robj_slice(PyObject *a, int ilow, int ihigh)
+{
+  SEXP robj, e, index;
+  PyObject *obj;
+  int robjLen, sliceLen, c;
+  int ii;
+  
+  robjLen = Robj_len(a);
+  
+  if (robjLen < 0)
+    return NULL;
+  
+  if (ilow < 0) {
+    PyErr_SetString(PyExc_IndexError, 
+		    "R object index out of range (lowest index is negative)");
+    return NULL;
+    //ilow = 0;
+  } else if (ilow > robjLen) {
+    PyErr_SetString(PyExc_IndexError, 
+		    "R object index out of range (lowest index > object length)");
+    return NULL;
+    //ilow = robjLen;
+  }
+  if (ihigh < ilow) {
+    PyErr_SetString(PyExc_IndexError, 
+		    "R object index out of range (highest index < lowest index)");
+    return NULL;
+    //ihigh = ilow;
+  } else if (ihigh > robjLen) {
+    PyErr_SetString(PyExc_IndexError, 
+		    "R object index out of range (highest index > object length)");
+    //return NULL;
+    ihigh = robjLen;
+  }
+  sliceLen = ihigh - ilow;
+  
+  /*   if (ilow >= robjLen || ilow < 0) { */
+  /*     PyErr_SetString(PyExc_IndexError, "R object index out of range"); */
+  /*     return NULL; */
+  /*   } */
+  
+  PROTECT(index = allocVector(INTSXP, sliceLen));
+
+  for (ii = 0; ii < sliceLen; ii++) {
+    INTEGER_POINTER(index)[ii] = ii + ilow + 1;
+  }
+  
+  PROTECT(e = allocVector(LANGSXP, 3));
+  SETCAR(e, get_item);
+  SETCAR(CDR(e), ((RobjObject *)a)->R_obj);
+  SETCAR(CDR(CDR(e)), index);
+
+  if (!(robj = do_eval_expr(e))) {
+    UNPROTECT(2);
+    return NULL;
+  }
+
+  UNPROTECT(2);
+
+  /* If there is a default mode, use it; otherwise, use the top mode. */
+  if (default_mode < 0)
+    c = TOP_MODE;
+  else
+    c = default_mode;
+  obj = to_Pyobj_with_mode(robj, c);
+  return obj;  
+}
+
+
+/* FIXME:
+ * Python 2.5 will feel happier with ssizeargfunc and ssizessizeargfunc
+ */
 /* We should implement sq_slice, sq_contains ... */
 static PySequenceMethods Robj_as_sequence = {
   (inquiry)Robj_len,              /* sq_length */
-  0,                            /* sq_concat */
-  0,                            /* sq_repeat */
-  (intargfunc)Robj_item,           /* sq_item */
-  0,                            /* sq_slice */
-  (intobjargproc)Robj_ass_item,     /* sq_ass_item */
-  0,                            /* sq_ass_slice */
-  0,                            /* sq_contains */
+  0,                              /* sq_concat */
+  0,                              /* sq_repeat */
+  (intargfunc)Robj_item,        /* sq_item */
+  (intintargfunc)Robj_slice,  /* sq_slice */
+  (intobjargproc)Robj_ass_item,   /* sq_ass_item */
+  0,                              /* sq_ass_slice */
+  0,                              /* sq_contains */
+  0,                              /* sq_inplace_concat */
+  0                               /* sq_inplace_repeat */
 };
 
 
@@ -1689,17 +1778,26 @@ void r_finalize(void)
     R_dot_Last();           
     R_RunExitFinalizers();  
     CleanEd();              
-    KillAllDevices();       
+#if (R_VERSION >= R_Version(2,7,0))
+    Rf_KillAllDevices();
+#else
+    KillAllDevices();
+#endif
+
+#if (R_VERSION >= R_Version(2,4,0)) 
+    R_CleanTempDir();
+#else
     if((tmpdir = getenv("R_SESSION_TMPDIR"))) {          
 
-#ifdef _WIN32
+#   ifdef _WIN32
       snprintf((char *)buf, 1024, "rmdir /S /Q %s", tmpdir); 
-#else
+#   else
       snprintf((char *)buf, 1024, "rm -rf %s", tmpdir);
-#endif
+#   endif
 
       R_system((char *)buf);
     }
+#endif 
 
     PrintWarnings();	/* from device close and .Last */
     R_gc();  /* Remove any remaining R objects from memory */
@@ -1709,7 +1807,7 @@ void r_finalize(void)
 static PyObject *
 r_cleanup(void)
 {
-  r_cleanup();
+  r_finalize();
   Py_INCREF(Py_None);
   return Py_None;
 }
@@ -1803,7 +1901,9 @@ RPyDoNothing( void )
 
 /* initialise embedded R; based on rproxy_impl.c from the R distribution */
 static void
-init_embedded_win32( void ) {
+init_embedded_win32(int argc, 
+		    char *argv[])
+{
   structRstart rp;
   Rstart Rp = &rp;
   char Rversion[25];
@@ -1856,7 +1956,7 @@ init_embedded_win32( void ) {
   Rp->CommandLineArgs = NULL;
   Rp->NumCommandLineArgs = 0;
 #else
-  R_set_command_line_arguments(0, NULL);
+  R_set_command_line_arguments(argc, argv);
 #endif
   R_SetParams(Rp); /* so R_ShowMessage is set */
   R_SizeFromEnv(Rp);
@@ -1875,7 +1975,6 @@ INIT_RPY(void)
   PyObject *m, *d;
   PyOS_sighandler_t old_int;
 #ifndef _WIN32
-  char *defaultargv[] = {"rpy", "-q", "--vanilla"};
   PyOS_sighandler_t old_usr1, old_usr2;
 #endif
   SEXP interact;
@@ -1899,7 +1998,16 @@ INIT_RPY(void)
   Robj_Type.tp_alloc = PyType_GenericAlloc;
 #endif
 
-  m = Py_InitModule(xstr(RPY_SHNAME), rpy_methods);
+  /* Initialize the module with its content */
+  if (PyType_Ready(&Robj_Type) < 0)
+    return;
+  m = Py_InitModule3(xstr(RPY_SHNAME), 
+		     rpy_methods,
+		     "Python interface to the R Programming Language");
+  Py_INCREF(&Robj_Type);
+  PyModule_AddObject(m, Robj_Type.tp_name, 
+		     (PyObject *)&Robj_Type);
+
   d = PyModule_GetDict(m);
 
   /* Save this interpreter */
@@ -1916,14 +2024,15 @@ INIT_RPY(void)
 #endif
 
 #ifdef _WIN32
-  init_embedded_win32();
+  init_embedded_win32(defaultargc,
+		      defaultargv);
 #else
-  Rf_initEmbeddedR( sizeof(defaultargv) / sizeof(defaultargv[0]),
-                    defaultargv);
+  Rf_initEmbeddedR(defaultargc,
+                   defaultargv);
 #endif
 
 
-#ifndef CSTACK_DEFNS
+#ifdef CSTACK_DEFNS
   /* Disable C stack checking, which is incompatible with use as a
      shared library. */
   R_CStackLimit = (uintptr_t)-1; 
