@@ -9,6 +9,9 @@ import sys
 
 class BooleanTestCase(unittest.TestCase):
 
+    def setup(self):
+        set_default_mode(NO_DEFAULT)
+
     def testTRUE(self):
         self.failUnless(r.typeof(r.TRUE) == 'logical' and
                         r.as_logical(r.TRUE))
