@@ -17,6 +17,10 @@ class IOTestCase(unittest.TestCase):
     def tearDown(self):
         sys.stdout = sys.__stdout__
         sys.stderr = sys.__stderr__
+        # reset i/o defaults
+        set_rpy_output(rpy_io.rpy_output)
+        set_rpy_input(rpy_io.rpy_input)
+
             
     def testIOstdin(self):
         def dummy(prompt, n):
@@ -35,13 +39,15 @@ class IOTestCase(unittest.TestCase):
         self.failUnless(out == ['[1]', ' 5', '\n'])
 
     def testIOshowfiles(self):
-        out = []
-        def dummy(files, headers, title, delete):
-            out.append('foo')
-            
-        set_rpy_showfiles(dummy)
-        r.help()
-        self.failUnless(out == ['foo'])
+        if sys.platform != 'win32':
+            out = []
+            def dummy(files, headers, title, delete):
+                out.append('foo')
+                print "Names curently defined"
+                dir()            
+                set_rpy_showfiles(dummy)
+                r.help()
+                self.failUnless(out == ['foo'])
 
     def testIOstdoutException(self):
         def stdout(s):
@@ -58,11 +64,12 @@ class IOTestCase(unittest.TestCase):
         self.assert_(r.readline() == '')
         
     def testIOshowfilesException(self):
-        def showfiles(files, headers, title, delete):
-            raise Exception
+        if sys.platform != 'win32':
+            def showfiles(files, headers, title, delete):
+                raise Exception
 
-        set_rpy_showfiles(showfiles)
-        self.assert_(r.help() == None)
+            set_rpy_showfiles(showfiles)
+            self.assert_(r.help() == None)
         
 if __name__ == '__main__':
     unittest.main()
