@@ -7,6 +7,7 @@ from rpy import *
 import sys
 import os
 import signal
+import time
 
 
 def sendsig():
@@ -15,6 +16,7 @@ def sendsig():
         raise KeyboardInterrupt
     else:
         os.kill(os.getpid(), signal.SIGINT)
+        time.sleep(1)
 
 class SigintTestCase(unittest.TestCase):
             
