@@ -27,7 +27,7 @@ class TypeConversionToPyTestCase(unittest.TestCase):
         assert( r(-2147483648) == r.NA )
 
     def testNAreal(self):
-        assert(r.NAN == r("as.numeric(NA)") )
+        assert(repr(r.NAN) == repr(r("as.numeric(NA)")) )
 
     def testNAstring(self):
         assert(r("as.character(NA)") == 'NA')
@@ -48,14 +48,14 @@ class TypeConversionToPyTestCase(unittest.TestCase):
     def testNAList(self):
         xi = [1,2,r.NA,r.NAN,4]
         assert(r.as_character(xi) == ['1', '2', 'NA', 'NA', '4'])
-        assert(r.as_numeric(xi) == [1.0, 2.0, r.NAN, r.NAN, 4.0])
-        assert(r.as_integer(xi) == [1, 2, r.NA, r.NA, 4])
+        assert(repr(r.as_numeric(xi)) == repr([1.0, 2.0, r.NAN, r.NAN, 4.0]))
+        assert(repr(r.as_integer(xi)) == repr([1, 2, r.NA, r.NA, 4]))
         assert(r.as_factor(xi) == ['1', '2', 'NA', 'NA', '4'])
         assert(r.is_na(xi) == [False, False, True, True, False] )
 
         xd = [1.01,2.02,r.NA,r.NAN,4.04]
         assert(r.as_character(xd) == ['1.01', '2.02', 'NA', 'NA', '4.04'])
-        assert(r.as_numeric(xd) == [1.01, 2.02, r.NAN, r.NAN, 4.04])
+        assert(repr(r.as_numeric(xd)) == repr([1.01, 2.02, r.NAN, r.NAN, 4.04]))
         assert(r.as_integer(xd) == [1, 2, r.NA, r.NA, 4])
         assert(r.as_factor(xd) == ['1.01', '2.02', 'NA', 'NA', '4.04'])
         assert(r.is_na(xd) == [False, False, True, True, False] )
