@@ -22,14 +22,14 @@ class UtilityTestCase(unittest.TestCase):
                   self.failUnless(get_default_mode() == CLASS_CONVERSION))()
         with_mode(PROC_CONVERSION, lambda:
                   self.failUnless(get_default_mode() == PROC_CONVERSION))()
-        self.failUnlessRaises(ValueError, lambda: with_mode(4, lambda: 4)())
+        self.failUnlessRaises(ValueError, lambda: with_mode(TOP_CONVERSION+1, lambda: 4)())
         self.failUnlessRaises(ValueError, lambda: with_mode(-2, lambda: 4)())
 
     def testRCode(self):
         with_mode(BASIC_CONVERSION,
                   lambda: self.failUnless(r("c(4,5)") == [4,5]))()
-        self.failUnlessRaises(RException, lambda: r("foo"))
-        self.failUnlessRaises(RException, lambda: r("[$%^"))
+        self.failUnlessRaises(RPyRException, lambda: r("foo"))
+        self.failUnlessRaises(RPyRException, lambda: r("[$%^"))
 
         
 if __name__ == '__main__':
